summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_holder.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
commit648ba4a456d3aad2825193ff8f3bd52a875783b5 (patch)
tree0b50d2253a0c85238cc4dcba5c4f949de3f0eb15 /kig/objects/object_holder.h
parent98a12d05a48814bec3870b9a6d5865475cfa1c95 (diff)
downloadtdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.tar.gz
tdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1212481 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kig/objects/object_holder.h')
-rw-r--r--kig/objects/object_holder.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kig/objects/object_holder.h b/kig/objects/object_holder.h
index 1d96e007..0afd3892 100644
--- a/kig/objects/object_holder.h
+++ b/kig/objects/object_holder.h
@@ -101,9 +101,9 @@ public:
*/
void draw( KigPainter& p, bool selected ) const;
/**
* Returns whether this object tqcontains the point \p p .
*/
- bool tqcontains( const Coordinate& p, const KigWidget& w, bool nv = false ) const;
+ bool contains( const Coordinate& p, const KigWidget& w, bool nv = false ) const;
/**
* Returns whether this object is in the rectangle \p r .
*/
@@ -101,9 +101,9 @@ public:
void draw( KigPainter& p, bool selected ) const;
/**
- * Returns whether this object tqcontains the point \p p .
+ * Returns whether this object contains the point \p p .
*/